@@ -212,7 +212,7 @@ int open_listen_socket( int port )
    
     /* create the socket, and set for non-blocking */
     if (esd_use_tcpip)
-      socket_listen=socket(AF_INET,SOCK_STREAM,0);
+      socket_listen=socket(AF_INET, SOCK_STREAM, 0);
     else
     {
       if (access(ESD_UNIX_SOCKET_DIR, R_OK | W_OK) == -1)
@@ -253,14 +253,14 @@ int open_listen_socket( int port )
 	    }
 	}
       unlink(ESD_UNIX_SOCKET_NAME);
-      socket_listen=socket(AF_UNIX,SOCK_STREAM,0);
+      socket_listen=socket(AF_UNIX, SOCK_STREAM, 0);
     }
-    if (socket_listen<0) 
+    if (socket_listen < 0) 
     {
 	fprintf(stderr,"Unable to create socket\n");
 	return( -1 );
     }
-    if (fcntl(socket_listen,F_SETFL,O_NONBLOCK)<0)
+    if (fcntl(socket_listen, F_SETFL, O_NONBLOCK) < 0)
     {
 	fprintf(stderr,"Unable to set socket to non-blocking\n");
 	return( -1 );
@@ -285,6 +285,7 @@ int open_listen_socket( int port )
     if (esd_use_tcpip)
     {
       /* set the listening information */
+      memset(&socket_addr, 0, sizeof(struct sockaddr_in));
       socket_addr.sin_family = AF_INET;
       socket_addr.sin_port = htons( port );
       if (esd_public)
@@ -301,6 +302,9 @@ int open_listen_socket( int port )
     }
     else
     {
+      mode_t old_umask;
+
+      old_umask = umask(0);
       socket_unix.sun_family=AF_UNIX;
       strncpy(socket_unix.sun_path, ESD_UNIX_SOCKET_NAME, sizeof(socket_unix.sun_path));
       if ( bind( socket_listen,
@@ -314,12 +318,7 @@ int open_listen_socket( int port )
 	    }
 	  exit(1);
 	}
-      /* let anyone access esd's socket - but we have authentication so they */
-      /* wont get far if they dont have the auth key */
-      chmod(ESD_UNIX_SOCKET_NAME, 
-	    S_IRUSR|S_IWUSR|S_IXUSR|
-	    S_IRGRP|S_IWGRP|S_IXGRP|
-	    S_IROTH|S_IWOTH|S_IXOTH);
+      umask(old_umask);
     }
     if (listen(socket_listen,16)<0)
     {
@@ -477,6 +476,9 @@ int main ( int argc, char *argv[] )
 	} else if ( !strcmp( argv[ arg ], "-spawnpid" ) ) {
 	    if ( ++arg < argc )
 		esd_spawnpid = atoi( argv[ arg ] );
+	} else if ( !strcmp( argv[ arg ], "-v" ) || !strcmp( argv[ arg ], "--version" ) ) {
+		fprintf(stderr, "Esound version " VERSION "\n");
+		exit (0);
 	} else if ( !strcmp( argv[ arg ], "-h" ) ) {
 	    fprintf( stderr, "Usage: esd [options]\n\n" );
 	    fprintf( stderr, "  -d DEVICE   force esd to use sound device DEVICE\n" );
