@@ -12,21 +12,12 @@ int esd_send_file( int esd, AFfilehandle au_file, int frame_length )
     /* data for transfer */
     char buf[ ESD_BUF_SIZE ];
     int frames_read;
-    int length, towrite, written;
     int buf_frames = ESD_BUF_SIZE / frame_length;
 
-    length = afGetTrackBytes( au_file, AF_DEFAULT_TRACK );
-
-    while ( length > 0 )
+    while ( ( frames_read = afReadFrames( au_file, AF_DEFAULT_TRACK, 
+					buf, buf_frames ) ) )
     {
-	frames_read = afReadFrames( au_file, AF_DEFAULT_TRACK, 
-				    buf, buf_frames );
-	towrite = frames_read * frame_length;
-	if ( towrite > length )
-	    towrite = length;
-	length -= towrite;
-	written = write ( esd, buf, towrite );
-	if ( written != towrite )
+	if ( write ( esd, buf, frames_read * frame_length ) <= 0)
 	    return 1;
     }
 
@@ -60,7 +51,11 @@ int esd_play_file( const char *name_prefix, const char *filename, int fallback )
     */
 
     /* open the audio file */
+#ifdef __EMX__
+    in_file = afOpenFile( filename, "rb", NULL );
+#else
     in_file = afOpenFile( filename, "r", NULL );
+#endif
     if ( !in_file )
 	return 0;
 
@@ -155,7 +150,11 @@ int esd_file_cache( int esd, const char *name_prefix, const char *filename )
     */
 
     /* open the audio file */
+#ifdef __EMX__
+    in_file = afOpenFile( filename, "rb", NULL );
+#else
     in_file = afOpenFile( filename, "r", NULL );
+#endif
     if ( !in_file )
 	return -1;
 
